@@ -1,92 +1,89 @@
-context("test_phe_proportion")
-
-
 # test calculations
 test_that("proportions and CIs calculate correctly",{
 
   expect_equal(data.frame(select(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator),1:6,8:9)),
                data.frame(select(slice(test_Prop,1:8),1:6,9:10)),
-               check.attributes=FALSE, check.names=FALSE, info="test default")
+               ignore_attr = TRUE, info="test default")
 
   expect_equal(data.frame(select(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                                                 confidence = c(0.95,0.998)),1:8,10:11)),
                data.frame(select(slice(test_Prop,1:8),1:10)),
-               check.attributes=FALSE, check.names=FALSE, info="test full output 2 CIs")
+               ignore_attr = TRUE, info="test full output 2 CIs")
 
   expect_equal(data.frame(select(phe_proportion(slice(test_Prop,9:16)[1:3], Numerator, Denominator,
                               multiplier = 100, type="full"),1:6,8:9)),
                data.frame(select(slice(test_Prop,9:16),1:6,9:10)),
-               check.attributes=FALSE, check.names=FALSE, info="test full, percentage")
+               ignore_attr = TRUE, info="test full, percentage")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                               multiplier = 1, type="standard")),
                data.frame(select(slice(test_Prop,1:8),1:6)),
-               check.attributes=FALSE, check.names=FALSE, info="test standard")
+               ignore_attr = TRUE, info="test standard")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                                          multiplier = 1, confidence = c(0.95,0.998), type="standard")),
                data.frame(select(slice(test_Prop,1:8),1:8)),
-               check.attributes=FALSE, check.names=FALSE, info="test standard 2 CIs")
+               ignore_attr = TRUE, info="test standard 2 CIs")
 
   expect_equal(data.frame(select(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                               type="full", confidence=99.8), 1:6,8:9)),
                data.frame(select(slice(test_Prop,1:8),1:4,7:10)),
-               check.attributes=FALSE, check.names=FALSE, info="test confidence")
+               ignore_attr = TRUE, info="test confidence")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator, type="value")),
                data.frame(select(slice(test_Prop,1:8),1:4)),
-               check.attributes=FALSE, check.names=FALSE, info="test value")
+               ignore_attr = TRUE, info="test value")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                                          confidence = c(0.95,0.998), type="value")),
                data.frame(select(slice(test_Prop,1:8),1:4)),
-               check.attributes=FALSE, check.names=FALSE, info="test value 2 CIs")
+               ignore_attr = TRUE, info="test value 2 CIs")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator, type="lower")),
                data.frame(select(slice(test_Prop,1:8),1:3,5)),
-               check.attributes=FALSE, check.names=FALSE, info="test lower")
+               ignore_attr = TRUE, info="test lower")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                                          confidence = c(0.95,0.998), type="lower")),
                data.frame(select(slice(test_Prop,1:8),1:3,5,7)),
-               check.attributes=FALSE, check.names=FALSE, info="test lower 2 CIs")
+               ignore_attr = TRUE, info="test lower 2 CIs")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator, type="upper")),
                data.frame(select(slice(test_Prop,1:8),1:3,6)),
-               check.attributes=FALSE, check.names=FALSE, info="test upper")
+               ignore_attr = TRUE, info="test upper")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator,
                                          confidence = c(0.95,0.998), type="upper")),
                data.frame(select(slice(test_Prop,1:8),1:3,6,8)),
-               check.attributes=FALSE, check.names=FALSE, info="test upper 2 CIs")
+               ignore_attr = TRUE, info="test upper 2 CIs")
 
   expect_equal(arrange(data.frame(select(phe_proportion(filter(test_Prop,Area %in% c("Area09","Area10","Area11"))[1:3],
                                                  Numerator, Denominator, type="full"),1:6,8:9)), Area),
                arrange(data.frame(select(filter(test_Prop,Area %in% c("Area09","Area10","Area11")),1:6,9:10)), Area),
-               check.attributes=FALSE, check.names=FALSE, info="test NAs")
+               ignore_attr = TRUE, info="test NAs")
 
   expect_equal(arrange(data.frame(phe_proportion(slice(test_Prop_g,1:8)[1:3], Numerator, Denominator, type="standard")), Area),
                arrange(select(data.frame(test_Prop_g_results[1:6]),1:6),Area),
-               check.attributes=FALSE, check.names=FALSE, info="test grouped")
+               ignore_attr = TRUE, info="test grouped")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop,1:8)[1:3], Numerator, Denominator, confidence = c(0.95, 0.998)))[1:6],
                data.frame(select(slice(test_Prop,1:8),1:9))[1:6],
-               check.attributes=FALSE, check.names=FALSE, info="test two CIs 95%")
+               ignore_attr = TRUE, info="test two CIs 95%")
 
   expect_equal(data.frame(select(phe_proportion(slice(test_Prop,9:16)[1:3], Numerator, Denominator,
                                                 multiplier = 100, confidence = c(0.95, 0.998)),1:4,7,8)),
                data.frame(select(slice(test_Prop,9:16),1:4,7:8)),
-               check.attributes=FALSE, check.names=FALSE, info="test two CIs 99.8%")
+               ignore_attr = TRUE, info="test two CIs 99.8%")
 
   expect_equal(data.frame(select(phe_proportion(slice(test_Prop,9:16)[1:3], Numerator, Denominator,
                                                 confidence = c(0.95, 0.998)),9)),
                data.frame(confidence = rep("95%, 99.8%",8), stringsAsFactors = FALSE),
-               check.attributes=FALSE, check.names=FALSE, info="test two CIs, metadata")
+               ignore_attr = TRUE, info="test two CIs, metadata")
 
   expect_equal(data.frame(phe_proportion(slice(test_Prop_g_results,1:8)[1:3], Numerator, Denominator,
                                                 confidence = NA)),
                data.frame(select(slice(test_Prop_g_results_no_CI,1:8),1:4,8)),
-               check.attributes=FALSE, check.names=FALSE, info="test no CIs")
+               ignore_attr = TRUE, info="test no CIs")
 
 })
 
