@@ -1,5 +1,3 @@
-context("test_phe_SII")
-
 # 1) Test calculations ----------------------------------------------------
 # Expect SII value to match exactly, and confidence limits to be within
 # given tolerance
@@ -58,7 +56,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(1,11), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test default with SE provided", tolerance = tol)
 
    # test same calculation, supplying upper and lower CLs rather than SE
@@ -72,9 +70,24 @@ test_that("SII and confidence limits calculate correctly",{
                                         rii = TRUE,
                                   type = "standard")),
                      data.frame(SII_test_grouped[c(1,11), c(3:5,16:21)]),
-                     check.attributes=FALSE, check.names=FALSE,
+                     ignore_attr = TRUE,
                      info="test default with CLs provided", tolerance = tol)
 
+     # test same calculation, outputting intercept value
+  expect_equal(data.frame(phe_sii(SII_test_grouped[1:20, 3:13],
+                                        Quantile, Population,
+                                        value_type = 0,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(246,256), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test default with intercept", tolerance = tol)
+
    # test function on ungrouped dataset
   SII_test_data <- ungroup(SII_test_grouped)
 
@@ -88,7 +101,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[1, c(16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test on ungrouped data", tolerance = tol)
 
     # test SII calculation at 99% confidence (inputted as decimal)
@@ -103,7 +116,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")), # SII confidence changed
                data.frame(SII_test_grouped[c(21,31), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test at 99% confidence (decimal)", tolerance = tol)
 
     # test SII calculation at 99% confidence (inputted as %)
@@ -117,7 +130,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")), # SII confidence changed
                data.frame(SII_test_grouped[c(21,31), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test at 99% confidence (%)", tolerance = tol)
 
   # test SII calculation on multiple confidence intervals (inputted as %)
@@ -130,8 +143,8 @@ test_that("SII and confidence limits calculate correctly",{
                                   repetitions = no_reps,
                                   rii = TRUE,
                                   type = "standard")), # SII confidence changed
-               data.frame(SII_test_grouped[c(226,236), c(3:5,16:18,22,19,23,20,24,21,25)]),
-               check.attributes=FALSE, check.names=FALSE,
+               data.frame(SII_test_grouped[c(226,236), c(3:5,16:18,19,22,23,20,21,24,25)]),
+               ignore_attr = TRUE,
                info="test at 95 and 99% confidence (%)", tolerance = tol)
 
     # test SII calculation on 100,000 repetitions
@@ -144,7 +157,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")), # No. repetitions changed
                data.frame(SII_test_grouped[c(41,51), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test on 10000 repetitions", tolerance = tol)
 
   # test SII calculation on quintiles instead of deciles
@@ -157,7 +170,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard"))[, 1:4], # only have SII available from Excel tool
                data.frame(SII_test_grouped[c(61,66), c(3:5,16)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test on quintiles", tolerance = tol)
 
   # *****************************
@@ -174,7 +187,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(71,81), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test rate with SE provided", tolerance = tol)
 
   # test same calculation, supplying upper and lower CLs (before transformation)
@@ -189,9 +202,107 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(71,81), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test rate with CLs provided", tolerance = tol)
 
+# test same calculation, outputting intercept value
+  expect_equal(data.frame(phe_sii(SII_test_grouped[71:90, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(266,276), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test rate with intercept", tolerance = tol)
+
+  # test calculation with log transformation of values,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[306:325, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(306,316), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test rate with transformation", tolerance = tol)
+
+  # test calculation with log transformation of values and negative multiplier,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[386:405, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        multiplier = -1, # Negative multiplier
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(386,396), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test rate with transformation and negative multiplier", tolerance = tol)
+
+  # test calculation with log transformation of values and 98% confidence intervals,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[406:425, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        confidence = 98, #98% CIs
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(406,416), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test rate with transformation and 98% cis", tolerance = tol)
+
+    # test calculation with log transformation of values and multiple confidence intervals,
+    expect_equal(data.frame(phe_sii(SII_test_grouped[366:385, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        confidence = c(95, 98), #95 and 98% CIs
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(366,376), c(3:5,16:26)]),
+                     ignore_attr = TRUE,
+                     info="test rate with transformation and multiple cis", tolerance = tol)
+
+    # test calculation with log transformation of values without RII,
+    expect_equal(data.frame(phe_sii(SII_test_grouped[426:445, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = FALSE,
+                                        intercept = FALSE,
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(426,436), c(3:5,16, 18:19)]),
+                     ignore_attr = TRUE,
+                     info="test rate with transformation without rii", tolerance = tol)
+
 
   # ***********************************
   # *** PROPORTION (value_type = 2) ***
@@ -207,7 +318,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(91,101), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with SE provided", tolerance = tol)
 
   # test same calculation, supplying upper and lower CLs (before transformation)
@@ -222,7 +333,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(91,101), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with CLs provided", tolerance = tol)
 
   # test same calculation, supplying count instead of value
@@ -236,9 +347,24 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(91,101), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with count provided", tolerance = tol)
 
+  # test same calculation, outputting intercept value
+  expect_equal(data.frame(phe_sii(SII_test_grouped[91:110, 3:13],
+                                        Quantile, Population,
+                                        value_type = 1,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(286,296), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test proportion with intercept", tolerance = tol)
+
   # test SII calculation with POSITIVE multiplier and RII
   expect_equal(data.frame(phe_sii(SII_test_grouped[111:130, 3:13],
                                   Quantile, Population,
@@ -251,7 +377,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(111,121), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with positive multiplier and RII", tolerance = tol)
 
   # test SII calculation with POSITIVE multiplier without RII
@@ -266,7 +392,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = FALSE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(111,121), c(3:5,16,18,19)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with positive multiplier without RII", tolerance = tol)
 
   # test SII calculation with NEGATIVE multiplier and RII
@@ -281,7 +407,7 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = TRUE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(131,141), c(3:5,16:21)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with negative multiplier and RII", tolerance = tol)
 
   # test SII calculation with NEGATIVE multiplier without RII
@@ -296,8 +422,91 @@ test_that("SII and confidence limits calculate correctly",{
                                   rii = FALSE,
                                   type = "standard")),
                data.frame(SII_test_grouped[c(131,141), c(3:5,16,18,19)]),
-               check.attributes=FALSE, check.names=FALSE,
+               ignore_attr = TRUE,
                info="test proportion with negative multiplier without RII", tolerance = tol)
+
+  # test calculation with logit transformation of values,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[326:345, 3:13],
+                                        Quantile, Population,
+                                        value_type = 2,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(326,336), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test proportion with transformation", tolerance = tol)
+
+  # test calculation with logit transformation of values and negative multiplier,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[346:365, 3:13],
+                                        Quantile, Population,
+                                        value_type = 2,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        multiplier = -1, # Multiplier set to -1
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(346,356), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test proportion with transformation and negative multiplier", tolerance = tol)
+
+  # test calculation with logit transformation of values and 98% ci,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[466:485, 3:13],
+                                        Quantile, Population,
+                                        value_type = 2,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        confidence = 98,
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(466,476), c(3:5,16:21,26)]),
+                     ignore_attr = TRUE,
+                     info="test proportion with transformation and 98% cis", tolerance = tol)
+
+  # test calculation with logit transformation of values and 95% and 98% ci,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[486:505, 3:13],
+                                        Quantile, Population,
+                                        value_type = 2,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        confidence = c(95, 98),
+                                        rii = TRUE,
+                                        intercept = TRUE, # Intercept set to true
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(486,496), c(3:5,16:26)]),
+                     ignore_attr = TRUE,
+                     info="test proportion with transformation and 95% and 98% cis", tolerance = tol)
+
+  # test calculation with logit transformation of values and 95% and 98% ci,
+  expect_equal(data.frame(phe_sii(SII_test_grouped[446:465, 3:13],
+                                        Quantile, Population,
+                                        value_type = 2,
+                                        value = Value,
+                                        lower_cl = LowerCL, # CLs supplied
+                                        upper_cl = UpperCL,
+                                        repetitions = no_reps,
+                                        rii = FALSE,
+                                        transform = TRUE, # Log transformation set to true
+                                  type = "standard")),
+                     data.frame(SII_test_grouped[c(446,456), c(3:5,16, 18:19)]),
+                     ignore_attr = TRUE,
+                     info="test proportion with transformation and no rii", tolerance = tol)
+
 })
 
 
@@ -423,6 +632,27 @@ test_that("errors are generated when invalid parameters are entered",{
                        confidence = 135),
                "all confidence levels must be between 90 and 100 or between 0.9 and 1",
                info = "invalid confidence limit pc - too high")
+        # transform set to true with indicator type =0
+  expect_error(phe_sii(SII_test_grouped[1:20, 3:13],
+                       Quantile,
+                       Population,
+                       value = Value,
+                       lower_cl = LowerCL, # CLs supplied
+                       upper_cl = UpperCL,
+                       transform = TRUE,
+                       value_type = 0),
+               "value_type should be 1 or 2 when transform is true",
+               info = "value_type should be 1 or 2 when transform is true")
+          # transform set to true and se provided
+  expect_error(phe_sii(SII_test_grouped[1:20, 3:13],
+                       Quantile,
+                       Population,
+                       value = Value,
+                       se = StandardError,
+                       transform = TRUE,
+                       value_type = 1),
+               "se to be missing when transform is true",
+               info = "se to be missing when transform is true")
 
 })
 
@@ -603,7 +833,7 @@ test_that("dimensions are correct when reliaibility stats requested",{
                                  repetitions = 1000,
                                  reliability_stat = TRUE,
                                  type = "full")),
-                     c(2,11))
+                     c(2,12))
 
         # check dimensions with default type = "full" WITHOUT reliability stats
         expect_equal(dim(phe_sii(SII_test_grouped[1:20, 3:13],
@@ -615,7 +845,7 @@ test_that("dimensions are correct when reliaibility stats requested",{
                                  repetitions = 1000,
                                  reliability_stat = FALSE,
                                  type = "full")),
-                     c(2,10))
+                     c(2,11))
 
 
         # Tests WITH RII
@@ -685,7 +915,7 @@ test_that("dimensions are correct when reliaibility stats requested",{
                                  rii = TRUE,
                                  reliability_stat = TRUE,
                                  type = "full")),
-                     c(2,15))
+                     c(2,16))
 
         # check dimensions with default type = "full" WITHOUT reliability stats
         expect_equal(dim(phe_sii(SII_test_grouped[1:20, 3:13],
@@ -698,6 +928,6 @@ test_that("dimensions are correct when reliaibility stats requested",{
                                  rii = TRUE,
                                  reliability_stat = FALSE,
                                  type = "full")),
-                     c(2,13))
+                     c(2,14))
 
 })
